function [predictedV, predictedM, predictedE] = run_algo(audioFile)
% First read the model
load modelsMulti
% Open the audio file!
[samples, frequency] = audioread(audioFile);
%[samples1, frequency1, ~] = wavread(audioFile);
samples = SampleRateConverter(samples, frequency, 8000);
%assert(frequency == 8000, 'frequency sampling must be 8KHz');
if (size(samples, 2) == 2)
    samples = samples(:, 1); % force mono
end
samples = samples(1:(length(samples)-rem(length(samples), 8000))); % truncate it to seconds
duration = length(samples) / 8000;
fE = fopen('input_1_rawE.txt', 'w');
fM = fopen('input_1_rawM.txt', 'w');
fV = fopen('input_1_rawV.txt', 'w');

% Extract the features from the audio
features = extractFeatures(samples, true);
% Normalize them
load maxFeatures 
maxFeatures = repmat(maxFeatures, size(features,1),1);
features = features ./ maxFeatures;

labels = zeros(size(features,1),1);
% Now, evaluate the SVMs
predictedV = svmpredict(labels, features(:,[1,9:21]), modelV, ' -q');
predictedM = svmpredict(labels, features(:,[4:7,9:21]), modelM, ' -q');
predictedE = svmpredict(labels, features(:,[4:7,9:21]), modelE, ' -q');

% Save the results to show nice audio visualization control
for t = 1:duration
    for x=1:8000
        i = (t-1)*8000+x;
        fprintf(fM, '%d %f\n', i, predictedM(t) * samples(i));
        fprintf(fV, '%d %f\n', i, predictedV(t) * samples(i));
        % If it is not Voice nor Music, it is Environment, even if
        % Environment was not detected.
        if (predictedM(t) == 0 && predictedV(t) == 0)
            fprintf(fE, '%d %f\n', i, samples(i));
        else
            fprintf(fE, '%d %f\n', i, predictedE(t) * samples(i));
        end
    end
end
fclose(fE);
fclose(fM);
fclose(fV);
fminmax = fopen('minmax.txt', 'w');
fprintf(fminmax, '%f %f\n', min(samples), max(samples));
fclose(fminmax);

% Save results in a file
fileID = fopen('results.txt','w');
for i=1:duration
    str = sprintf('Second %d: ', i);
    if (predictedE(i) == 1) 
        str = strcat(str, 'E,');
    end
    if (predictedV(i) == 1) 
        str = strcat(str, 'V,');
    end
    if (predictedM(i) == 1) 
        str = strcat(str, 'M,');
    end
    if (predictedV(i) == 1 || predictedM(i) == 1 || predictedE(i) == 1)
        str = str(1:end-1);
    else
        str = strcat(str,'E');
    end
    fprintf(fileID,'%s\n',str);
end
fclose(fileID);
end
